@@ -1,3 +1,5 @@
+from typing import Dict, List
+
 from fastapi_utils.cbv import cbv
 from fastapi_utils.inferring_router import InferringRouter
 
@@ -6,6 +8,7 @@ from connect.eaas.core.constants import (
     ADMIN_PAGES_ATTR_NAME,
     ANVIL_CALLABLE_ATTR_NAME,
     ANVIL_KEY_VAR_ATTR_NAME,
+    DEVOPS_PAGES_ATTR_NAME,
     EVENT_INFO_ATTR_NAME,
     GUEST_ENDPOINT_ATTR_NAME,
     MODULE_PAGES_ATTR_NAME,
@@ -23,7 +26,7 @@ def event(event_type, statuses=None):
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import event
     from connect.eaas.core.extension import EventsApplicationBase
 
@@ -42,11 +45,10 @@ def event(event_type, statuses=None):
             pass
     ```
 
-    **Parameters:**
-
-    * **event_type** - The type of event this handler is for.
-    * **statuses** - List of statuses of the event that this handler
-    want to receive.
+    Args:
+        event_type (str): The type of event this handler is for.
+        statuses (List[str]): List of statuses of the event that this handler
+            want to receive.
 
     !!! note
         The list of statuses is required for `background` event types
@@ -73,7 +75,7 @@ def schedulable(name, description):
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import schedulable
     from connect.eaas.core.extension import EventsApplicationBase
 
@@ -87,10 +89,9 @@ def schedulable(name, description):
             pass
     ```
 
-    **Parameters:**
-
-    * **name** - The name of this schedulable method.
-    * **description** - Description of what this schedulable method do.
+    Args:
+        name (str): The name of this schedulable method.
+        description (str): Description of what this schedulable method do.
 
     !!! note
         The `name` and `description` arguments are used by the
@@ -144,9 +145,8 @@ def variables(variables):
         pass
     ```
 
-    **Parameters:**
-
-    * **variables** - The list of environment variables you want to initialize.
+    Args:
+        variables (List[Dict]): The list of environment variables you want to initialize.
     """
     def wrapper(cls):
         if hasattr(cls, VARIABLES_INFO_ATTR_NAME):
@@ -169,7 +169,7 @@ def anvil_key_variable(name):
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import anvil_key_variable
     from connect.eaas.core.extension import AnvilApplicationBase
 
@@ -179,9 +179,8 @@ def anvil_key_variable(name):
         pass
     ```
 
-    **Parameters:**
-
-    * **name** - Name of the environment variable.
+    Args:
+        name (str): Name of the environment variable.
 
     !!! note
         This environment variable does not need to be
@@ -209,7 +208,7 @@ def anvil_callable(summary=None, description=None):
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import anvil_callable, anvil_key_variable
     from connect.eaas.core.extension import AnvilApplicationBase
 
@@ -224,6 +223,10 @@ def anvil_callable(summary=None, description=None):
         def say_hello(self, name):
             return f'Hello {name}'
     ```
+
+    Args:
+        summary (str): Summary of the callable.
+        description (str): Description of the callable.
     """
     def wrapper(func):
         setattr(
@@ -246,7 +249,7 @@ def guest():
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import guest, router, web_app
     from connect.eaas.core.extension import WebApplicationBase
 
@@ -271,7 +274,7 @@ def guest():
     return wrapper
 
 
-def account_settings_page(label, url):
+def account_settings_page(label: str, url: str):
     """
     Class decorator for Web Application that declare which html page
     must be rendererd within the `Account Settings` module of Connect UI
@@ -279,7 +282,7 @@ def account_settings_page(label, url):
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import (
         account_settings_page, router, web_app,
     )
@@ -292,10 +295,9 @@ def account_settings_page(label, url):
         pass
     ```
 
-    **Parameters:**
-
-    * **label** - the label to use for such page.
-    * **url** - the url path to the html page including `/static`.
+    Args:
+        label (str): The label to use for such page.
+        url (str): The url path to the html page including `/static`.
     """
     def wrapper(cls):
         setattr(cls, ACCOUNT_SETTINGS_PAGE_ATTR_NAME, {'label': label, 'url': url})
@@ -303,14 +305,14 @@ def account_settings_page(label, url):
     return wrapper
 
 
-def module_pages(label, url, children=None):
+def module_pages(label: str, url: str, children: List[Dict] = None):
     """
     Class decorator for Web Application that declare the main page
     for a web application and optionally a list of children pages.
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import (
         module_pages, router, web_app,
     )
@@ -332,11 +334,10 @@ def module_pages(label, url, children=None):
         pass
     ```
 
-    **Parameters:**
-
-    * **label** - the label to use for such page.
-    * **url** - the url path to the html page including `/static`.
-    * **children** - optional list of children pages.
+    Args:
+        label (str): The label to use for such page.
+        url (str): The url path to the html page including `/static`.
+        children (List[Dict]): Optional list of children pages.
 
     !!! note
         Your extension pages will be rendered using a `Tabs` component
@@ -357,7 +358,7 @@ def module_pages(label, url, children=None):
     return wrapper
 
 
-def admin_pages(pages):
+def admin_pages(pages: List[Dict]):
     """
     Class decorator for Web Application that declare a list of
     admin pages.
@@ -366,7 +367,7 @@ def admin_pages(pages):
 
     Usage:
 
-    ``` python
+    ``` py3
     from connect.eaas.core.decorators import (
         admin_pages, router, web_app,
     )
@@ -386,9 +387,8 @@ def admin_pages(pages):
         pass
     ```
 
-    **Parameters:**
-
-    * **pages** - optional list of admin pages.
+    Args:
+        pages (List[Dict]): Optional list of admin pages.
     """
     def wrapper(cls):
         setattr(cls, ADMIN_PAGES_ATTR_NAME, pages)
@@ -396,17 +396,103 @@ def admin_pages(pages):
     return wrapper
 
 
-def transformation(name, description, edit_dialog_ui):
+def transformation(name: str, description: str, edit_dialog_ui: str):
+    """
+    Mark a method of an Transformations Application as a tranformation
+    function.
+
+    Usage:
+
+    ``` py3
+    from connect.eaas.core.decorators import transformation
+    from connect.eaas.core.extension import EventsApplicationBase
+
+    class MyTransformationsApplication(TransformationsApplicationBase):
+
+        @transformation(
+            'Split column by delimiter',
+            'Split a column into multiple columns based on a delimiter',
+            '/static/configure_split_by_delimiter.html',
+        )
+        def split_by_delimiter(self, row):
+            pass
+    ```
+
+    Args:
+        name (str): The name of this transformation method.
+        description (str): Description of what this transformation method do.
+        edit_dialog_ui (str): Path to the html page that allow configuring
+        this transformation.
+    """
+    def wrapper(func):
+        setattr(
+            func,
+            TRANSFORMATION_ATTR_NAME,
+            {
+                'method': func.__name__,
+                'name': name,
+                'description': description,
+                'edit_dialog_ui': edit_dialog_ui,
+            },
+        )
+        return func
+    return wrapper
+
+
+def devops_pages(pages: List[Dict]):
+    """
+    Class decorator for Web Application that declare a list of
+    devops pages that will be displayed.
+    These pages are shown as additional tabs in the main devops page.
+
+    Usage:
+
+    ``` py3
+    from connect.eaas.core.decorators import (
+        devops_pages, router, web_app,
+    )
+    from connect.eaas.core.extension import WebApplicationBase
+
+
+    @web_app(router)
+    @devops_pages(
+        [
+            {
+                'label': 'My tab 1',
+                'url': '/static/tab1.html',
+            },
+        ],
+    )
+    class MyWebApp(WebApplicationBase):
+        pass
+    ```
+
+    Args:
+        pages (List[Dict]): List of devops pages including the label and the url.
+    """
     def wrapper(cls):
-        setattr(cls, TRANSFORMATION_ATTR_NAME, {
-            'name': name,
-            'description': description,
-            'edit_dialog_ui': edit_dialog_ui,
-            'class_fqn': f'{cls.__module__}.{cls.__name__}',
-        })
+        setattr(cls, DEVOPS_PAGES_ATTR_NAME, pages)
         return cls
     return wrapper
 
 
 router = InferringRouter()
 web_app = cbv
+"""
+This decorator is required to be used if you want to declare any
+endpoint.
+
+Usage:
+
+``` py3
+from connect.eaas.core.decorators import (
+    router, web_app,
+)
+from connect.eaas.core.extension import WebApplicationBase
+
+
+@web_app(router)
+class MyWebApp(WebApplicationBase):
+    pass
+```
+"""
