@@ -1,4 +1,10 @@
-from typing import Any, List, Literal, Optional, Union
+from typing import (
+    Any,
+    List,
+    Literal,
+    Optional,
+    Union,
+)
 
 from pydantic import BaseModel as PydanticBaseModel, Field
 from pydantic.utils import DUNDER_ATTRIBUTES
@@ -142,7 +148,7 @@ class Schedulable(BaseModel):
 
 
 class Transformation(BaseModel):
-    class_fqn: str
+    method: str
     name: str
     description: str
     edit_dialog_ui: str
