@@ -1,7 +1,8 @@
-from fastapi import Request
-from fastapi.responses import JSONResponse, PlainTextResponse
+import os
 
 from connect.client import ClientError
+from fastapi import Request
+from fastapi.responses import JSONResponse, PlainTextResponse
 
 
 def obfuscate_header(key, value):
@@ -29,3 +30,11 @@ def client_error_exception_handler(request: Request, exc: ClientError):
                 'errors': exc.errors,
             },
         )
+
+
+def get_correlation_id(connect_correlation_id):
+    if type(connect_correlation_id) != str:
+        return None
+    operation_id = connect_correlation_id[3:34]
+    span_id = os.urandom(8).hex()
+    return f'00-{operation_id}-{span_id}-01'
